<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

# townshipAccounts

Create an accounts object

**Parameters**

-   `db` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** – instance of a level db. See <https://npmjs.com/level>
-   `config` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** – configuration object

**Examples**

```javascript
var townshipAccounts = require('township-accounts')
var level = require('level')
var db = level('db')

var accounts = townshipAccounts(db, {
  secret: 'not a secret'
})
```

# register

Create an account

**Parameters**

-   `options` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** – email address that corresponds to an account
    -   `options.email` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – email address that corresponds to an account
    -   `options.password` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – password that corresponds to an account
    -   `options.scopes` **[Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)** – access scopes for an account
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with `error` and `accountData` arguments

**Examples**

```javascript
var creds = {
  email: 'user@example.com',
  password: 'notverysecret',
  scopes: ['example:read']
}

accounts.register(creds, function (err, account) {
  if (err) return console.log(err)
  console.log(account.key, account.token)
})
```

# login

Log in to an account

**Parameters**

-   `options` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** – email address that corresponds to an account
    -   `options.email` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – email address that corresponds to an account
    -   `options.password` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – password that corresponds to an account
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with `error` and `account` arguments

**Examples**

```javascript
var creds = {
  email: 'user@example.com',
  password: 'notverysecret'
}

accounts.login(creds, function (err, account) {
  if (err) return console.log(err)
  console.log(account.key, account.token)
})
```

# logout

Log out of an account

**Parameters**

-   `token` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – the active token for an account
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with an `error` argument

**Examples**

```javascript
accounts.logout(token, function (err) {
  if (err) return console.log(err)
})
```

# findbyEmail

Find an account by email

**Parameters**

-   `email` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – email address that corresponds to an account
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with `error` and `accountData` arguments

**Examples**

```javascript
accounts.findByEmail('user@example.com', function (err, accountData) {
  if (err) return console.log(err)
  console.log(accountData)
})
```

# updatePassword

Update password of an account

**Parameters**

-   `options` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** – email address that corresponds to an account
    -   `options.email` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – email address that corresponds to an account
    -   `options.password` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – password that corresponds to an account
    -   `options.newPassword` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – new password for an account
-   `token` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – the active token for an account
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with `error` and `account` arguments

**Examples**

```javascript
var creds = {
  email: 'user@example.com',
  password: 'notverysecret',
  newPassword: 'still not very secret',
  token: token
}

accounts.updatePassword(creds, function (err, account) {
  if (err) return console.log(err)
  console.log(account.key, account.token)
})
```

# authorize

Authorize account using access scopes

**Parameters**

-   `accountKey` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – the key for an account
-   `scopes` **[Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)** – the scopes your are checking for in the account's access permissions
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with an `error` argument

**Examples**

```javascript
accounts.authorize(key, ['example:read'], function (err) {
  if (err) return console.log(err)
})
```

# authorizeByEmail

Authorize account using access scopes via their email

**Parameters**

-   `email` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – the email address associated with an account
-   `scopes` **[Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)** – the scopes your are checking for in the account's access permissions
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with an `error` argument

**Examples**

```javascript
accounts.authorizeByEmail('user@example.com', ['example:read'], function (err) {
  if (err) return console.log(err)
})
```

# updateScopes

Update the access scopes of an account

**Parameters**

-   `key` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – the key associated with an account
-   `scopes` **[Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)** – the new scopes of the account. note that this completely replaces the old scopes array
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with an `error` argument

**Examples**

```javascript
accounts.updateScopes(key, ['example:read'], function (err) {
  if (err) return console.log(err)
})
```

# verifyToken

verify that a token is valid

**Parameters**

-   `token` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** – the JWT created when registering or logging in
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** – callback function called with `error` and `accountData` arguments

**Examples**

```javascript
accounts.updateScopes(key, ['example:read'], function (err) {
  if (err) return console.log(err)
})
```
